@@ -83,28 +83,14 @@ def update(pkgname, verfilename, revision_number=False, loud=False, abort_if_sna
         (output, errput) = p.communicate()
         rc = p.returncode
     if rc != 0:
-        try:
-            p = subprocess.Popen(["realdarcs.exe"] + cmd, stdout=PIPE, stderr=PIPE, universal_newlines=True)
-        except OSError, ose:
-            if ose.errno == 2 and '~' in os.environ['PATH']:
-                expanded_path = os.environ['PATH'].replace('~', os.path.expanduser('~'))
-                msg = ("WARNING: 'realdarcs.exe' was not found. However '~' was found in your PATH. \n"
-                       "Please note that bugs in python cause it to fail to traverse '~' in \n"
-                       "the user's PATH.  Please fix your path, e.g. \nPATH=%s" )
-                log.warn(msg % (expanded_path,))
-            pass
+        if errput:
+            log.info("%s: darcs wrote to stderr: '%s'" % (EXE_NAME, errput,))
+        if os.path.exists(verfilename):
+            log.info("%s: didn't version tags with 'darcs changes', and %s already exists, so leaving it alone." % (EXE_NAME, verfilename,))
+            return (0, read_version_py(verfilename))
         else:
-            (output, errput) = p.communicate()
-            rc = p.returncode
-        if rc != 0:
-            if errput:
-                log.info("%s: darcs wrote to stderr: '%s'" % (EXE_NAME, errput,))
-            if os.path.exists(verfilename):
-                log.info("%s: Failure from attempt to find version tags with 'darcs changes', and %s already exists, so leaving it alone." % (EXE_NAME, verfilename,))
-                return (0, read_version_py(verfilename))
-            else:
-                log.warn("%s: Failure from attempt to find version tags with 'darcs changes', and %s doesn't exist." % (EXE_NAME, verfilename))
-            return (rc, None)
+            log.warn("%s: didn't find version tags with 'darcs changes', and %s doesn't exist." % (EXE_NAME, verfilename))
+        return (rc, None)
 
     # Filter out bad chars that can cause the XML parser to give up in despair.
     # (Thanks to lelit of the tailor project and ndurner and warner for this hack.)
